==> connector-http-base-8.4.5-sources.jar: io/camunda/connector/http/base/auth/BasicAuthentication.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.connector.http.base.auth;

import com.google.api.client.http.HttpHeaders;
import com.google.common.base.Objects;
import io.camunda.connector.feel.annotation.FEEL;
import io.camunda.connector.generator.java.annotation.TemplateProperty;
import io.camunda.connector.generator.java.annotation.TemplateSubType;
import jakarta.validation.constraints.NotEmpty;
import java.util.function.Function;

@TemplateSubType(id = BasicAuthentication.TYPE, label = "Basic")
public final class BasicAuthentication implements Authentication {
  @TemplateProperty(ignore = true)
  private static final String SPEC_PASSWORD_EMPTY_PATTERN = "SPEC_PASSWORD_EMPTY_PATTERN";

  @TemplateProperty(ignore = true)
  private static final Function<String, String> SPEC_PASSWORD =
      (psw) -> psw.equals(SPEC_PASSWORD_EMPTY_PATTERN) ? "" : psw;

  @FEEL
  @NotEmpty
  @TemplateProperty(group = "authentication")
  private String username;

  @FEEL
  @NotEmpty
  @TemplateProperty(group = "authentication")
  private String password;

  @Override
  public void setHeaders(final HttpHeaders headers) {
    headers.setBasicAuthentication(username, SPEC_PASSWORD.apply(password));
  }

  public String getUsername() {
    return username;
  }

  public void setUsername(final String username) {
    this.username = username;
  }

  public String getPassword() {
    return password;
  }

  public void setPassword(final String password) {
    this.password = password;
  }

  @Override
  public boolean equals(final Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    BasicAuthentication that = (BasicAuthentication) o;
    return Objects.equal(username, that.username) && Objects.equal(password, that.password);
  }

  @Override
  public int hashCode() {
    return Objects.hashCode(super.hashCode(), username, password);
  }

  @Override
  public String toString() {
    return "BasicAuthentication {"
        + "username='[REDACTED]'"
        + ", password='[REDACTED]'"
        + "}; Super: "
        + super.toString();
  }

  @TemplateProperty(ignore = true)
  public static final String TYPE = "basic";
}

==> connector-http-base-8.5.1-sources.jar: io/camunda/connector/http/base/auth/BasicAuthentication.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.connector.http.base.auth;

import com.google.api.client.http.HttpHeaders;
import io.camunda.connector.feel.annotation.FEEL;
import io.camunda.connector.generator.java.annotation.TemplateProperty;
import io.camunda.connector.generator.java.annotation.TemplateSubType;
import jakarta.validation.constraints.NotEmpty;

@TemplateSubType(id = BasicAuthentication.TYPE, label = "Basic")
public record BasicAuthentication(
    @FEEL @NotEmpty @TemplateProperty(group = "authentication") String username,
    @FEEL
        @TemplateProperty(
            group = "authentication",
            constraints = @TemplateProperty.PropertyConstraints(notEmpty = true))
        String password)
    implements Authentication {

  @TemplateProperty(ignore = true)
  public static final String TYPE = "basic";

  @Override
  public void setHeaders(final HttpHeaders headers) {
    String passwordForHeader = password;
    // checking against "SPEC_PASSWORD_EMPTY_PATTERN" to prevent breaking change
    if (password == null || password.equals("SPEC_PASSWORD_EMPTY_PATTERN")) {
      passwordForHeader = "";
    }
    headers.setBasicAuthentication(username, passwordForHeader);
  }
}
